@@ -9,6 +9,8 @@ from pypayment import Payment, PaymentStatus, NotAuthorized, PaymentGettingError
 
 
 class PayOkPaymentType(Enum):
+    """PayOk payment type enum."""
+
     CARD = "cd"
     """Payment with bank card."""
     QIWI = "qw"
@@ -46,6 +48,8 @@ class PayOkPaymentType(Enum):
 
 
 class PayOkCurrency(Enum):
+    """PayOk payment currency enum."""
+
     RUB = "RUB"
     """Russian ruble."""
     UAH = "UAH"
@@ -59,6 +63,8 @@ class PayOkCurrency(Enum):
 
 
 class PayOkPayment(Payment):
+    """PayOk payment class."""
+
     authorized = False
     _api_key: str
     _api_id: int
@@ -169,7 +175,7 @@ class PayOkPayment(Payment):
             "currency": "RUB",
         }
         sign_str = "|".join(map(str, (data["amount"], data["payment"], data["shop"], data["currency"], data["desc"], PayOkPayment._shop_secret_key)))
-        data["sign"] = hashlib.md5(sign_str.encode()).hexdigest()
+        data["sign"] = hashlib.md5(sign_str.encode()).hexdigest()  # skipcq: BAN-B324, PTC-W1003
         try:
             response = requests.post(PayOkPayment._PAY_URL, data=data)
         except Exception as e:
@@ -192,7 +198,7 @@ class PayOkPayment(Payment):
         }
 
         sign_str = "|".join(map(str, (data["amount"], data["payment"], data["shop"], data["currency"], data["desc"], PayOkPayment._shop_secret_key)))
-        data["sign"] = hashlib.md5(sign_str.encode()).hexdigest()
+        data["sign"] = hashlib.md5(sign_str.encode()).hexdigest()  # skipcq: BAN-B324, PTC-W1003
 
         return PayOkPayment._PAY_URL + "?" + urllib.parse.urlencode(data)
 
@@ -205,7 +211,6 @@ class PayOkPayment(Payment):
         }
         try:
             response = requests.post(PayOkPayment._TRANSACTION_URL, data=data).json()
-            print(response)
         except Exception as e:
             raise PaymentGettingError(e)
 
