@@ -13,3 +13,9 @@ def test_default_status():
     with pytest.raises(TypeError):
         payment = Payment(1)
         payment.status
+
+
+def test_default_income():
+    with pytest.raises(TypeError):
+        payment = Payment(1)
+        payment.income
